<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>LXQtWorldClock</name>
    <message>
        <location filename="../lxqtworldclock.cpp" line="246"/>
        <source>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d MMM yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</source>
        <translation>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d &apos;de&apos; MMM &apos;de&apos; yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</translation>
    </message>
</context>
<context>
    <name>LXQtWorldClockConfiguration</name>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="14"/>
        <source>World Clock Settings</source>
        <translation>Configurações do Relógio Mundial</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="24"/>
        <source>Display &amp;format</source>
        <translation>Exibir &amp;formato</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="30"/>
        <source>&amp;Time</source>
        <translation>&amp;Tempo</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="39"/>
        <source>F&amp;ormat:</source>
        <translation>F&amp;ormato:</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="50"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="176"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="272"/>
        <source>Short</source>
        <translation>Curto</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="55"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="181"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="277"/>
        <source>Long</source>
        <translation>Longo</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="60"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="287"/>
        <source>Custom</source>
        <translation>Personalizado</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="89"/>
        <source>Sho&amp;w seconds</source>
        <translation>E&amp;xibir segundos</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="96"/>
        <source>Pad &amp;hour with zero</source>
        <translation>Mostrar &amp;hora com zero</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="116"/>
        <source>T&amp;ime zone</source>
        <translation>Fuso Horár&amp;io</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="128"/>
        <source>&amp;Position:</source>
        <translation>&amp;Posição:</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="138"/>
        <source>For&amp;mat:</source>
        <translation>For&amp;mato:</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="149"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="238"/>
        <source>Below</source>
        <translation>Abaixo</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="154"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="243"/>
        <source>Above</source>
        <translation>Acima</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="159"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="248"/>
        <source>Before</source>
        <translation>Antes</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="164"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="253"/>
        <source>After</source>
        <translation>Depois</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="186"/>
        <source>Offset from UTC</source>
        <translation>Deslocamento de UTC</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="191"/>
        <source>Abbreviation</source>
        <translation>Abreviação</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="431"/>
        <source>IANA id</source>
        <translation>Id IANA</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="201"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="436"/>
        <location filename="../lxqtworldclockconfiguration.cpp" line="586"/>
        <source>Custom name</source>
        <translation>Nome personalizado</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="103"/>
        <source>&amp;Use 12-hour format</source>
        <translation>&amp;Usar formato 12-horas</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="196"/>
        <source>Location identifier</source>
        <translation>Identificador de localização</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="212"/>
        <source>&amp;Date</source>
        <translation>&amp;Data</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="227"/>
        <source>Po&amp;sition:</source>
        <translation>Po&amp;sição:</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="261"/>
        <source>Fo&amp;rmat:</source>
        <translation>Fo&amp;rmato:</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="282"/>
        <source>ISO 8601</source>
        <translation>ISO 8601</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="316"/>
        <source>Show &amp;year</source>
        <translation>Exibir A&amp;no</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="323"/>
        <source>Show day of wee&amp;k</source>
        <translation>Exibir dia da &amp;semana</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="330"/>
        <source>Pad d&amp;ay with zero</source>
        <translation>Pad di&amp;a com zero</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="337"/>
        <source>&amp;Long month and day of week names</source>
        <translation>Nomes &amp;longos do mês e dia da semana</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="350"/>
        <source>Ad&amp;vanced manual format</source>
        <translation>Formato do manual avançado</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="377"/>
        <source>&amp;Customise ...</source>
        <translation>&amp;Customizar ...</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="403"/>
        <source>Time &amp;zones</source>
        <translation>Fusos &amp;horários</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="446"/>
        <source>&amp;Add ...</source>
        <translation>&amp;Adicionar ...</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="456"/>
        <source>&amp;Remove</source>
        <translation>&amp;Remover</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="466"/>
        <source>Set as &amp;default</source>
        <translation>Definir como pa&amp;drão</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="476"/>
        <source>&amp;Edit custom name ...</source>
        <translation>&amp;Editar nome personalizado ...</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="486"/>
        <source>Move &amp;up</source>
        <translation>Mover para ci&amp;ma</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="496"/>
        <source>Move do&amp;wn</source>
        <translation>Mover para bai&amp;xo</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="519"/>
        <source>&amp;General</source>
        <translation>&amp;Geral</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="525"/>
        <source>Auto&amp;rotate when the panel is vertical</source>
        <translation>Gi&amp;rar automaticamente quando o painel está na vertical</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="535"/>
        <source>Show &amp;week numbers in popup calendar</source>
        <translation>Exibir os números da &amp;semana no calendário pop-up</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="545"/>
        <source>S&amp;how tooltip</source>
        <translation>E&amp;xibir dicas</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.cpp" line="107"/>
        <source>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d MMM yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</source>
        <translation>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br /&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d MMM yyyy&apos;&lt;br /&gt;&apos;TT&apos;&lt;/font&gt;&apos;</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.cpp" line="585"/>
        <source>Input custom time zone name</source>
        <translation>Inserir nome do fuso horário personalizado</translation>
    </message>
</context>
<context>
    <name>LXQtWorldClockConfigurationManualFormat</name>
    <message>
        <location filename="../lxqtworldclockconfigurationmanualformat.ui" line="14"/>
        <source>World Clock Manual Format Configuration</source>
        <translation>Configuração Manual do Formato Relógio Mundial</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationmanualformat.ui" line="83"/>
        <source>&lt;h1&gt;Custom Date/Time Format Syntax&lt;/h1&gt;
&lt;p&gt;A date pattern is a string of characters, where specific strings of characters are replaced with date and time data from a calendar when formatting or used to generate data for a calendar when parsing.&lt;/p&gt;
&lt;p&gt;The Date Field Symbol Table below contains the characters used in patterns to show the appropriate formats for a given locale, such as yyyy for the year. Characters may be used multiple times. For example, if y is used for the year, &apos;yy&apos; might produce &apos;99&apos;, whereas &apos;yyyy&apos; produces &apos;1999&apos;. For most numerical fields, the number of characters specifies the field width. For example, if h is the hour, &apos;h&apos; might produce &apos;5&apos;, but &apos;hh&apos; produces &apos;05&apos;. For some characters, the count specifies whether an abbreviated or full form should be used, but may have other choices, as given below.&lt;/p&gt;
&lt;p&gt;Two single quotes represents a literal single quote, either inside or outside single quotes. Text within single quotes is not interpreted in any way (except for two adjacent single quotes). Otherwise all ASCII letter from a to z and A to Z are reserved as syntax characters, and require quoting if they are to represent literal characters. In addition, certain ASCII punctuation characters may become variable in the future (eg &quot;:&quot; being interpreted as the time separator and &apos;/&apos; as a date separator, and replaced by respective locale-sensitive characters in display).&lt;br /&gt;&lt;/p&gt;
&lt;table border=&quot;1&quot; width=&quot;100%&quot; cellpadding=&quot;4&quot; cellspacing=&quot;0&quot;&gt;
&lt;tr&gt;&lt;th width=&quot;20%&quot;&gt;Code&lt;/th&gt;&lt;th&gt;Meaning&lt;/th&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;d&lt;/td&gt;&lt;td&gt;the day as number without a leading zero (1 to 31)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;dd&lt;/td&gt;&lt;td&gt;the day as number with a leading zero (01 to 31)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ddd&lt;/td&gt;&lt;td&gt;the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;dddd&lt;/td&gt;&lt;td&gt;the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;M&lt;/td&gt;&lt;td&gt;the month as number without a leading zero (1-12)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MM&lt;/td&gt;&lt;td&gt;the month as number with a leading zero (01-12)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MMM&lt;/td&gt;&lt;td&gt;the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MMMM&lt;/td&gt;&lt;td&gt;the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;yy&lt;/td&gt;&lt;td&gt;the year as two digit number (00-99)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;yyyy&lt;/td&gt;&lt;td&gt;the year as four digit number&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;h&lt;/td&gt;&lt;td&gt;the hour without a leading zero (0 to 23 or 1 to 12 if AM/PM display)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;hh&lt;/td&gt;&lt;td&gt;the hour with a leading zero (00 to 23 or 01 to 12 if AM/PM display)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;H&lt;/td&gt;&lt;td&gt;the hour without a leading zero (0 to 23, even with AM/PM display)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;HH&lt;/td&gt;&lt;td&gt;the hour with a leading zero (00 to 23, even with AM/PM display)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;m&lt;/td&gt;&lt;td&gt;the minute without a leading zero (0 to 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;mm&lt;/td&gt;&lt;td&gt;the minute with a leading zero (00 to 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;s&lt;/td&gt;&lt;td&gt;the second without a leading zero (0 to 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ss&lt;/td&gt;&lt;td&gt;the second with a leading zero (00 to 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;AP &lt;i&gt;or&lt;/i&gt; A&lt;/td&gt;&lt;td&gt;use AM/PM display. &lt;b&gt;A/AP&lt;/b&gt; will be replaced by either &quot;AM&quot; or &quot;PM&quot;.&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ap &lt;i&gt;or&lt;/i&gt; a&lt;/td&gt;&lt;td&gt;use am/pm display. &lt;b&gt;a/ap&lt;/b&gt; will be replaced by either &quot;am&quot; or &quot;pm&quot;.&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;t&lt;/td&gt;&lt;td&gt;the timezone (e.g. &quot;CEST&quot;)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;T&lt;/td&gt;&lt;td&gt;the offset from UTC&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TT&lt;/td&gt;&lt;td&gt;the timezone IANA id&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTT&lt;/td&gt;&lt;td&gt;the timezone abbreviation&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTT&lt;/td&gt;&lt;td&gt;the timezone short display name&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTTT&lt;/td&gt;&lt;td&gt;the timezone long display name&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTTTT&lt;/td&gt;&lt;td&gt;the timezone custom name. You can change it the &apos;Time zones&apos; tab of the configuration window&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;
&lt;br /&gt;&lt;b&gt;Notes:&lt;/b&gt; &lt;ul&gt;&lt;li&gt;Any characters in the pattern that are not in the ranges of [&apos;a&apos;..&apos;z&apos;] and [&apos;A&apos;..&apos;Z&apos;] will be treated as quoted text. For instance, characters like &apos;:&apos;, &apos;.&apos;, &apos; &apos;, &apos;#&apos; and &apos;@&apos; will appear in the resulting time text even they are not enclosed within single quotes. The single quote is used to &apos;escape&apos; letters. Two single quotes in a row, whether inside or outside a quoted sequence, represent a &apos;real&apos; single quote.&lt;/li&gt;&lt;li&gt;Minimal update interval is 1 second. If z or zzz is configured time is shown with the milliseconds fraction, but not updated on millisecond basis (avoiding big performance hit).&lt;/li&gt;&lt;ul&gt;
</source>
        <translation>&lt;h1&gt; Sintaxe de formato de data / hora personalizado &lt;/h1&gt;
&lt;p&gt; Um padrão de data é uma sequência de caracteres, em que sequências específicas de caracteres são substituídas por dados de data e hora de um calendário durante a formatação ou usados para gerar dados para um calendário durante a análise. &lt;/p&gt;
&lt;p&gt; A Tabela de símbolos do campo de data abaixo contém os caracteres usados em padrões para mostrar os formatos apropriados para um determinado local, como aaaa para o ano. Os caracteres podem ser usados várias vezes. Por exemplo, se y for usado para o ano, &apos;yy&apos; pode produzir &apos;99&apos;, enquanto &apos;yyyy&apos; produz &apos;1999&apos;. Para a maioria dos campos numéricos, o número de caracteres especifica a largura do campo. Por exemplo, se h é a hora, &apos;h&apos; pode produzir &apos;5&apos;, mas &apos;hh&apos; produz &apos;05&apos;. Para alguns caracteres, a contagem especifica se uma forma abreviada ou completa deve ser usada, mas pode haver outras opções, conforme mostrado abaixo. &lt;/p&gt;
&lt;p&gt; Duas aspas simples representam uma aspa simples literal, dentro ou fora das aspas simples. O texto entre aspas simples não é interpretado de forma alguma (exceto para duas aspas simples adjacentes). Caso contrário, todas as letras ASCII de a a z e de A a Z são reservadas como caracteres de sintaxe e requerem aspas para representar caracteres literais. Além disso, certos caracteres de pontuação ASCII podem se tornar variáveis no futuro (por exemplo, &quot;:&quot; sendo interpretado como o separador de hora e &apos;/&apos; como um separador de data, e substituído pelos respectivos caracteres sensíveis ao local no display). &lt;br /&gt; &lt; / p&gt;
&lt;table border = &quot;1&quot; width = &quot;100%&quot; cellpadding = &quot;4&quot; cellspacing = &quot;0&quot;&gt;
&lt;tr&gt; &lt;th width = &quot;20%&quot;&gt; Código &lt;/th&gt; &lt;th&gt; Significado &lt;/th&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;d&lt;/td&gt; &lt;td&gt; o dia como um número sem zero à esquerda (1 a 31) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;dd&lt;/td&gt; &lt;td&gt; o dia como um número com um zero à esquerda (01 a 31) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ddd&lt;/td&gt; &lt;td&gt; o nome abreviado do dia localizado (por exemplo, &apos;Seg&apos; para &apos;Sol&apos;). &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;dddd&lt;/td&gt; &lt;td&gt; o nome longo do dia localizado (por exemplo, &apos;Segunda-feira&apos; a &apos;Domingo&apos;). &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;M&lt;/td&gt; &lt;td&gt; o mês como um número sem zero à esquerda (1-12) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MM&lt;/td&gt; &lt;td&gt; o mês como um número com um zero à esquerda (01-12) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MMM&lt;/td&gt; &lt;td&gt; o nome abreviado do mês localizado (por exemplo, &apos;Jan&apos; a &apos;Dez&apos;). &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MMMM&lt;/td&gt; &lt;td&gt; o nome longo do mês localizado (por exemplo, &apos;janeiro&apos; a &apos;dezembro&apos;). &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;yy&lt;/td&gt; &lt;td&gt; o ano como um número de dois dígitos (00-99) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;yyyy&lt;/td&gt; &lt;td&gt; o ano como um número de quatro dígitos &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;h&lt;/td&gt; &lt;td&gt; a hora sem zero à esquerda (0 a 23 ou 1 a 12 se exibir AM / PM) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;hh&lt;/td&gt; &lt;td&gt; a hora com um zero à esquerda (00 a 23 ou 01 a 12 se exibir AM / PM) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;H&lt;/td&gt; &lt;td&gt; a hora sem zero à esquerda (0 a 23, mesmo com exibição de AM / PM) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;HH&lt;/td&gt; &lt;td&gt; a hora com um zero à esquerda (00 a 23, mesmo com exibição de AM / PM) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;m&lt;/td&gt; &lt;td&gt; o minuto sem zero à esquerda (0 a 59) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;mm&lt;/td&gt; &lt;td&gt; o minuto com um zero à esquerda (00 a 59) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;s&lt;/td&gt; &lt;td&gt; o segundo sem zero à esquerda (0 a 59) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ss&lt;/td&gt; &lt;td&gt; o segundo com um zero à esquerda (00 a 59) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; AP &lt;i&gt; ou &lt;/i&gt; A &lt;/td&gt; &lt;td&gt; usa exibição AM / PM. &lt;b&gt; A / AP &lt;/b&gt; será substituído por &quot;AM&quot; ou &quot;PM&quot;. &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; ap &lt;i&gt; ou &lt;/i&gt; a &lt;/td&gt; &lt;td&gt; use a exibição am / pm. &lt;b&gt; a / ap &lt;/b&gt; será substituído por &quot;am&quot; ou &quot;pm&quot;. &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;t&lt;/td&gt; &lt;td&gt; o fuso horário (por exemplo, &quot;CEST&quot;) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;T&lt;/td&gt; &lt;td&gt; o deslocamento do UTC &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TT&lt;/td&gt; &lt;td&gt; o ID do fuso horário IANA &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTT&lt;/td&gt; &lt;td&gt; a abreviação do fuso horário &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTT&lt;/td&gt; &lt;td&gt; o nome de exibição abreviado do fuso horário &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTTT&lt;/td&gt; &lt;td&gt; o nome de exibição longo do fuso horário &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTTTT&lt;/td&gt; &lt;td&gt; o nome personalizado do fuso horário. Você pode alterá-lo na guia &apos;Fusos horários&apos; da janela de configuração &lt;/td&gt; &lt;/tr&gt; &lt;/table&gt;
&lt;br /&gt; &lt;b&gt; Observações: &lt;/b&gt; &lt;ul&gt; &lt;li&gt; Quaisquer caracteres no padrão que não estejam nos intervalos de [&apos;a&apos; .. &apos;z&apos;] e [&apos;A&apos; .. &apos;Z &apos;] será tratado como texto citado. Por exemplo, caracteres como &apos;:&apos;, &apos;.&apos;, &apos;&apos;, &apos;#&apos; E &apos;@&apos; aparecerão no texto da hora resultante, mesmo que não estejam entre aspas simples. A aspa simples é usada para &apos;escapar&apos; letras. Duas aspas simples consecutivas, seja dentro ou fora de uma sequência entre aspas, representam uma aspa simples &apos;real&apos;. &lt;/li&gt; &lt;li&gt; O intervalo mínimo de atualização é de 1 segundo. Se z ou zzz for configurado, o tempo é mostrado com a fração de milissegundos, mas não atualizado em uma base de milissegundos (evitando grande impacto no desempenho). &lt;/li&gt; &lt;ul&gt;
</translation>
    </message>
</context>
<context>
    <name>LXQtWorldClockConfigurationTimeZones</name>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="14"/>
        <source>World Clock Time Zones</source>
        <translation>Fusos Horários Relógio Mundial</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="36"/>
        <source>Time zone</source>
        <translation>Fuso horário</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="41"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="46"/>
        <source>Comment</source>
        <translation>Comentário</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="51"/>
        <source>Country</source>
        <translation>País</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.cpp" line="117"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.cpp" line="120"/>
        <location filename="../lxqtworldclockconfigurationtimezones.cpp" line="128"/>
        <source>Other</source>
        <translation>Outro</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.cpp" line="129"/>
        <source>Local timezone</source>
        <translation>Fuso horário local</translation>
    </message>
</context>
</TS>
